pub struct FFSStateRef(/* private fields */);Implementations
Sourceimpl FFSStateRef
impl FFSStateRef
Sourcepub fn total_events(&self) -> NumEvents
pub fn total_events(&self) -> NumEvents
int: the total number of events that have occurred in the state.
Sourcepub fn clone_state(&self) -> PyState
pub fn clone_state(&self) -> PyState
Sourcepub fn canvas_view<'py>(
this: Bound<'py, Self>,
_py: Python<'py>,
) -> PyResult<Bound<'py, PyArray2<Tile>>>
pub fn canvas_view<'py>( this: Bound<'py, Self>, _py: Python<'py>, ) -> PyResult<Bound<'py, PyArray2<Tile>>>
NDArray[np.uint]: a direct, mutable view of the state’s canvas. This is potentially unsafe.
Sourcepub fn canvas_copy<'py>(
this: &Bound<'_, Self>,
py: Python<'py>,
) -> PyResult<Bound<'py, PyArray2<Tile>>>
pub fn canvas_copy<'py>( this: &Bound<'_, Self>, py: Python<'py>, ) -> PyResult<Bound<'py, PyArray2<Tile>>>
Create a copy of the state’s canvas. This is safe, but can’t be modified and is slower than
canvas_view.
Returns
NDArray[np.uint] a copy of the state’s canvas.
Sourcepub fn tracking_copy(this: &Bound<'_, Self>) -> PyResult<RustAny>
pub fn tracking_copy(this: &Bound<'_, Self>) -> PyResult<RustAny>
pub fn __repr__(&self) -> String
Sourcepub fn rate_array<'py>(&self, py: Python<'py>) -> Bound<'py, PyArray2<f64>> ⓘ
pub fn rate_array<'py>(&self, py: Python<'py>) -> Bound<'py, PyArray2<f64>> ⓘ
Return a cloned copy of an array with the total possible next event rate for each point in the canvas. This is the deepest level of the quadtree for tree-based states.
Returns
NDArray[np.uint]
Sourcepub fn total_rate(&self) -> f64
pub fn total_rate(&self) -> f64
float: the total rate of possible next events for the state.