pub struct AnnealProtocol {
pub temperatures: (f64, f64),
pub holds: (f64, f64),
pub anneal_time: f64,
pub seconds_per_step: f64,
pub scaffold_count: usize,
}Fields
temperatures: (f64, f64)A tuple with initial and final temperatures (in C)
holds: (f64, f64)A tuple with:
- How long to hold the initial temperature for before starting the temperature decremenet
- How long to hold the final temperature for before finishing the anneal
anneal_time: f64How long to spend in the phase where the temperature is decrementing from the initial to the final temp
seconds_per_step: f64How long to spend at each temperature
scaffold_count: usizeImplementations
Sourceimpl AnnealProtocol
impl AnnealProtocol
Sourcepub fn generate_arrays(&self) -> (Vec<f64>, Vec<f64>)
pub fn generate_arrays(&self) -> (Vec<f64>, Vec<f64>)
Generates two arrays:
(Vec<temperatures>, Vec<times>)
pub fn run_system<St: State>( &self, sdc: SDC, state: St, ) -> Result<(Vec<Vec<u32>>, Vec<f64>, Vec<f64>), GrowError>
pub fn run_anneal_default_system( &self, sdc: SDC, ) -> Result<(Vec<Vec<u32>>, Vec<f64>, Vec<f64>), GrowError>
pub fn run_many_anneals_default_system( &self, sdcs: Vec<SDC>, ) -> Vec<Result<(Vec<Vec<u32>>, Vec<f64>, Vec<f64>), GrowError>>