SDC

Struct SDC 

pub struct SDC {
Show 15 fields pub strand_names: Vec<String>, pub glue_names: Vec<String>, pub quencher_id: Option<Tile>, pub quencher_concentration: Molar, pub reporter_id: Option<Tile>, pub fluorophore_concentration: Molar, pub scaffold: Array1<Glue>, pub strand_concentration: Array1<Molar>, pub scaffold_concentration: Molar, pub strand_glues: Array2<Glue>, pub colors: Vec<[u8; 4]>, pub kf: PerMolarSecond, pub friends_btm: Vec<Vec<Tile>>, pub delta_g_matrix: Array2<KcalPerMol>, pub entropy_matrix: Array2<KcalPerMolKelvin>, /* private fields */
}

Fields

strand_names: Vec<String>glue_names: Vec<String>quencher_id: Option<Tile>

Identifies the strand that serves as a binding site for the quencher

quencher_concentration: Molar

Concentration of the quencher

reporter_id: Option<Tile>

Name of the reporter tile

fluorophore_concentration: Molar

Concentration of the fluorophore,

scaffold: Array1<Glue>

Glues on the scaffold. We only allow a single 1D scaffold here, which is repeated over the i-axis.

strand_concentration: Array1<Molar>

All strands in the system, they are represented by tiles with only glue on the south, west, and east (nothing can stick to the top of a strand)

scaffold_concentration: Molar

The concentration of the scaffold

strand_glues: Array2<Glue>

Glues of a given strand by id

Note that the glues will be sorted in the following manner: [ (0) – [left glue, bottom glue, right glue] … (n) – [left glue, bottom glue, right glue] ]

colors: Vec<[u8; 4]>

Each strand will be given a color so that it can be easily identified when illustrated

kf: PerMolarSecond

The (de)attachment rates will depend on this constant(for the system) value

friends_btm: Vec<Vec<Tile>>

Set of tiles that can stick to scaffold gap with a given glue

delta_g_matrix: Array2<KcalPerMol>

Delta G at 37 degrees C in the formula to generate the glue strengths

entropy_matrix: Array2<KcalPerMolKelvin>

S in the formula to generate the glue strengths

Implementations

Source

impl SDC

pub fn change_temperature_to(&mut self, temperature: impl Into<Kelvin>)

Update the systems temperature. Accepts either Celsius or Kelvin as input.

pub fn n_scaffolds<S: State>(&self, state: &S) -> usize

pub fn total_tile_count<S: State>(&self, state: &S, tile: Tile) -> usize

pub fn fill_energy_array(&mut self)

Fill the energy_bonds array

pub fn monomer_detachment_rate_at_point<S: State>( &self, state: &S, scaffold_point: PointSafe2, ) -> PerSecond

pub fn monomer_change_rate_at_point<S: State>( &self, state: &S, scaffold_point: PointSafe2, ) -> PerSecond

pub fn choose_monomer_change_at_point<S: State>( &self, state: &S, point: PointSafe2, acc: PerSecond, ) -> (bool, PerSecond, Event, f64)

pub fn choose_monomer_attachment_at_point<S: State>( &self, state: &S, point: PointSafe2, acc: PerSecond, ) -> (bool, PerSecond, Event, f64)

pub fn choose_monomer_detachment_at_point<S: State>( &self, state: &S, point: PointSafe2, acc: PerSecond, ) -> (bool, PerSecond, Event, f64)

pub fn system_states(&self) -> Vec<Vec<u32>>

pub fn boltzman_function(&self, attachments: &[u32]) -> f64

pub fn partition_function_full(&self) -> f64

pub fn partition_function(&self) -> BigFloat

Notes:

  • This only works for a single scaffold type.
pub fn partial_partition_function( &self, constrain_at_loc: Vec<Vec<Tile>>, ) -> BigFloat

This calculates a partial partition for the system. At each location, it takes a Vec. If the Vec is empty, then no constraints are applied. If the Vec is not empty, then the partition function is only calculated for the tiles in the Vec. 0 corresponds to the site being empty.

pub fn log_partition_function(&self) -> f64

pub fn log_partial_partition_function( &self, constrain_at_loc: Vec<Vec<Tile>>, ) -> f64

pub fn probability_of_constrained_configurations( &self, constrain_at_loc: Vec<Vec<Tile>>, ) -> f64

pub fn probability_of_state(&self, system: &[u32]) -> f64

Source

impl SDC

pub fn mfe_configuration(&self) -> (Vec<Tile>, f64)

Get the mfe configuration, as well as its energy

Source

impl SDC

pub fn from_params(params: SDCParams) -> Self

Source

impl SDC

pub fn py_evolve<'py>( &mut self, state: PyStateOrStates<'py>, for_events: Option<u64>, total_events: Option<u64>, for_time: Option<f64>, total_time: Option<f64>, size_min: Option<u32>, size_max: Option<u32>, for_wall_time: Option<f64>, require_strong_bound: bool, show_window: bool, start_window_paused: bool, parallel: bool, initial_timescale: Option<f64>, initial_max_events_per_sec: Option<u64>, py: Python<'py>, ) -> PyResult<Py<PyAny>>

Evolve a state (or states), with some bounds on the simulation.

If evolving multiple states, the bounds are applied per-state.

Parameters

state : State or Sequence[State] The state or states to evolve. for_events : int, optional Stop evolving each state after this many events. total_events : int, optional Stop evelving each state when the state’s total number of events (including previous events) reaches this. for_time : float, optional Stop evolving each state after this many seconds of simulated time. total_time : float, optional Stop evolving each state when the state’s total time (including previous steps) reaches this. size_min : int, optional Stop evolving each state when the state’s number of tiles is less than or equal to this. size_max : int, optional Stop evolving each state when the state’s number of tiles is greater than or equal to this. for_wall_time : float, optional Stop evolving each state after this many seconds of wall time. require_strong_bound : bool Require that the stopping conditions are strong, i.e., they are guaranteed to be eventually satisfied under normal conditions. show_window : bool Show a graphical UI window while evolving (requires rgrow-gui to be installed, and a single state). start_window_paused : bool If show_window is True, start the GUI window in a paused state. Defaults to True. parallel : bool Use multiple threads. initial_timescale : float, optional If show_window is True, set the initial timescale (sim_time/real_time) in the GUI. None means unlimited. initial_max_events_per_sec : int, optional If show_window is True, set the initial max events per second limit in the GUI. None means unlimited.

Returns

EvolveOutcome or ListEvolveOutcome The outcome (stopping condition) of the evolution. If evolving a single state, returns a single outcome.

pub fn print_debug(&self)

pub fn write_json(&self, filename: &str) -> Result<(), RgrowError>

Write the system to a JSON file.

Parameters

filename : str The name of the file to write to.

pub fn read_json(filename: &str) -> Result<Self, RgrowError>

Read a system from a JSON file.

Parameters

filename : str The name of the file to read from.

Returns

Self

pub fn py_place_tile( &self, state: &mut PyState, point: (usize, usize), tile: u32, replace: bool, ) -> Result<f64, RgrowError>

Place a tile at a point in the given state.

This updates tile counts and rates but does not increment the event counter or record events in the state tracker.

Parameters

state : PyState The state to modify. point : tuple of int The coordinates at which to place the tile (i, j). tile : int The tile number to place. replace : bool, optional If True (default), any existing tile at the target site is removed first. If False, raises an error if the site is occupied.

Returns

float The energy change from placing the tile.

pub fn py_find_first_critical_state( &mut self, end_state: &PyState, config: CriticalStateConfig, py: Python<'_>, ) -> PyResult<Option<CriticalStateResult>>

pub fn py_find_last_critical_state( &mut self, end_state: &PyState, config: CriticalStateConfig, py: Python<'_>, ) -> PyResult<Option<CriticalStateResult>>