TileCounts

Trait TileCounts 

pub trait TileCounts {
    // Required methods
    fn tile_counts(&self) -> ArrayView1<'_, NumTiles>;
    fn count_of_tile(&self, tile: Tile) -> NumTiles;
    fn update_attachment(&mut self, tile: Tile);
    fn update_detachment(&mut self, tile: Tile);
}

Required Methods

fn tile_counts(&self) -> ArrayView1<'_, NumTiles>

fn count_of_tile(&self, tile: Tile) -> NumTiles

fn update_attachment(&mut self, tile: Tile)

Change the tile count based on the tile attaching

fn update_detachment(&mut self, tile: Tile)

Change the tile count based on the tile detaching

Implementors