pub struct EvolveBounds {
pub for_events: Option<NumEvents>,
pub total_events: Option<NumEvents>,
pub for_time: Option<f64>,
pub total_time: Option<f64>,
pub size_min: Option<NumTiles>,
pub size_max: Option<NumTiles>,
pub for_wall_time: Option<Duration>,
}Fields
for_events: Option<NumEvents>Stop if this number of events has taken place during this evolve call.
total_events: Option<NumEvents>Stop if this number of events has been reached in total for the state.
for_time: Option<f64>Stop if this amount of (simulated) time has passed during this evolve call.
total_time: Option<f64>Stop if this amount of (simulated) time has passed in total for the state.
size_min: Option<NumTiles>Stop if the number of tiles is equal to or less than this number.
size_max: Option<NumTiles>Stop if the number of tiles is equal to or greater than this number.
for_wall_time: Option<Duration>Stop after this amount of (real) time has passed.
Implementations
Sourceimpl EvolveBounds
impl EvolveBounds
Sourceimpl EvolveBounds
impl EvolveBounds
Sourcepub fn is_weakly_bounded(&self) -> bool
pub fn is_weakly_bounded(&self) -> bool
Will the EvolveBounds actually bound anything, or is it just null, such that the simulation will continue until a ZeroRate or an error? Note that this includes weak bounds (size minimum and maximum) that may never be reached.
pub fn is_strongly_bounded(&self) -> bool
Sourceimpl EvolveBounds
impl EvolveBounds